@@ -92,7 +92,8 @@ def run(meter, duration):
         'current_indices': list(range(2, num_sensors + 2)),
         'rotations': np.zeros(num_sensors).tolist(),
         'scale_factor': 1.0,
-        'merge': True})
+        'merge': True,
+        'pq': True})
 
     my_prep = prep.Prep()
     prep_future = asyncio.ensure_future(
