@@ -1,4 +1,3 @@
-
 import joule.utils.time
 import numpy as np
 import bisect
@@ -36,7 +35,7 @@ Arguments
 -------------
 config:
   this should be a JSON encoded dict with the
-  following properties 
+  following properties
 
  {
     'current_indices':  [N,] #current columns (1 indexed)
@@ -44,7 +43,8 @@ config:
     'nshift': 1         #amount to shift window
     'nharm': 4          #number of odd harmonics to compute
     'scale_factor': 1.0 #scale result to watts
-    'merge': False      #set to use a single prep output stream
+    'merge': True       #set to use a single prep output stream
+    'pq': False         #set to compute PQ data (clear to compute mag/phase)
  }
 """
 
@@ -122,7 +122,6 @@ class Prep(FilterModule):
                         start_i = 1+ph*width
                         end_i = start_i+width
                         cols = [0]+list(range(start_i, end_i))
-#                        print(cols)
                         await ph_outputs[ph].write(data[:, cols])
 
             processed = 0
@@ -167,12 +166,17 @@ class Prep(FilterModule):
                         for k in range(nharm):
                             Fk = F[2 * k + 1] * \
                                 np.e**(rot * 1j * (2 * k + 1)) / lag_correction
-                            out[0, ph * nharm * 2 + 2 * k + 1] = - \
-                                np.imag(Fk)  # Pk
-                            out[0, ph * nharm * 2 + 2 * k + 2] = - \
-                                np.real(Fk)  # Qk
-                    # scale the result
-                    out[:, 1:] *= self.scale_factor
+                            # compute output values
+                            if self.pq:
+                                out_a = -np.imag(Fk) * self.scale_factor  # Pk
+                                out_b = -np.real(Fk) * self.scale_factor  # Qk
+                            else:
+
+                                out_a = np.abs(Fk) * self.scale_factor  # VA
+                                out_b = (np.angle(Fk)+np.pi/2)*2/np.pi  # pf
+                            out[0, ph * nharm * 2 + 2 * k + 1] = out_a
+                            out[0, ph * nharm * 2 + 2 * k + 2] = out_b
+
                     await insert_if_nonoverlapping(out)
                     zc.consume(1)
                     return idx_max
@@ -222,7 +226,8 @@ class Prep(FilterModule):
         self.nharm = config['nharm']
         self.scale_factor = config['scale_factor']
         self.merge = config['merge']
-
+        self.pq = config['pq']
+        
 
 def main():
     filter = Prep()
