@@ -17,7 +17,7 @@ from .prep import Prep
 
 ARGS_DESC = """
 Operation
---------------    
+--------------
 process full filter stack:
 
                             ,--iv       ,--sinefit
@@ -71,8 +71,13 @@ class RawToPrep(FilterModule):
         parser.add_argument("--merge-prep",
                             action="store_true",
                             dest="merge_prep",
-                            help="store prep in a single stream")    
-        
+                            help="store prep in a single stream")
+        # --pq = False
+        parser.add_argument("--pq",
+                            action="store_true",
+                            dest="pq",
+                            help="compute PQ instead of mag/phase")
+
     async def run(self, parsed_args, inputs, outputs):
 
         # configure logger
@@ -92,7 +97,8 @@ class RawToPrep(FilterModule):
             'reconstructor':  self._build_recon_configs(my_meter),
             'sinefit':        self._build_sinefit_configs(my_meter),
             'prep':           self._build_prep_configs(my_meter,
-                                                       parsed_args.merge_prep)
+                                                       parsed_args.merge_prep,
+                                                       parsed_args.pq)
         }
 
         tasks = self._run_filters_as_tasks(
@@ -217,7 +223,7 @@ class RawToPrep(FilterModule):
         config['max_freq'] = 70
         return config
 
-    def _build_prep_configs(self, meter, merge_output):
+    def _build_prep_configs(self, meter, merge_output, pq):
 
         def _compute_rotations(meter):
             if(meter['type'] == 'noncontact'):
@@ -249,12 +255,15 @@ class RawToPrep(FilterModule):
         config['rotations'] = _compute_rotations(meter)
         config['scale_factor'] = _compute_scale_factor(meter)
         config['merge'] = merge_output
+        config['pq'] = pq
         return config
 
+    
 def main():
     filter = RawToPrep()
     filter.start()
 
+    
 if __name__ == "__main__":
     main()
 
